OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a> { /* private fields */ }
A view into an occupied entry in a Mapping.

Implementations

Source

impl<'a> OccupiedEntry<'a>

pub fn key(&self) -> Option<YamlNode>

Return the key of this entry as a YamlNode.

Returns None for malformed entries with no key node.

pub fn get(&self) -> Option<YamlNode>

Return the current value of this entry as a YamlNode.

Returns None for malformed entries with no value node.

pub fn get_mapping(&self) -> Option<Mapping>

Return the value as a nested Mapping, if it is one.

pub fn get_sequence(&self) -> Option<Sequence>

Return the value as a nested Sequence, if it is one.

pub fn set_value(&self, value: impl AsYaml)

Replace the value of this entry with value.

pub fn remove_entry(self) -> MappingEntry

Remove this entry from the mapping and return the removed MappingEntry handle. The returned entry is detached from the tree.