PositionedParseError

Struct PositionedParseError 

pub struct PositionedParseError {
    pub message: String,
    pub range: TextPosition,
    pub code: Option<String>,
    pub kind: ParseErrorKind,
}
A positioned parse error containing location information.

Fields

message: String

The error message

range: TextPosition

The text range where the error occurred

code: Option<String>

Optional error code for categorization

kind: ParseErrorKind

Structured error kind

Implementations

Source

impl PositionedParseError

pub fn start_position(&self, source_text: &str) -> LineColumn

Get the line and column where this error starts (if source text is available).

Arguments
  • source_text - The original YAML source text
Returns

LineColumn with 1-indexed line and column numbers.

Examples
use yaml_edit::{YamlFile, Parse};
use std::str::FromStr;

let text = "invalid:\n  - [unclosed";
let parse = Parse::parse_yaml(text);

if let Some(err) = parse.positioned_errors().first() {
    let pos = err.start_position(text);
    assert_eq!(pos.line, 2);
}
pub fn end_position(&self, source_text: &str) -> LineColumn

Get the line and column where this error ends (if source text is available).

Arguments
  • source_text - The original YAML source text
Returns

LineColumn with 1-indexed line and column numbers.