Document

Struct Document 

pub struct Document(/* private fields */);
A single YAML document

Implementations

Source

impl Document

pub fn new() -> Document

Create a new document

pub fn root_node(&self) -> Option<SyntaxNode<Lang>>

Get the root node of this document (could be mapping, sequence, or scalar)

pub fn as_mapping(&self) -> Option<Mapping>

Get this document as a mapping, if it is one

pub fn as_sequence(&self) -> Option<Sequence>

Get this document as a sequence, if it is one

pub fn as_scalar(&self) -> Option<Scalar>

Get this document as a scalar, if it is one