pub struct Document(/* private fields */);Expand description
A single YAML document
Implementations
Sourceimpl Document
impl Document
Sourcepub fn root_node(&self) -> Option<SyntaxNode<Lang>>
pub fn root_node(&self) -> Option<SyntaxNode<Lang>>
Get the root node of this document (could be mapping, sequence, or scalar)
Sourcepub fn as_mapping(&self) -> Option<Mapping>
pub fn as_mapping(&self) -> Option<Mapping>
Get this document as a mapping, if it is one
Sourcepub fn as_sequence(&self) -> Option<Sequence>
pub fn as_sequence(&self) -> Option<Sequence>
Get this document as a sequence, if it is one